@@ -28,6 +28,7 @@
 #include "oxygencomboboxengine.h"
 #include "oxygencomboboxentryengine.h"
 #include "oxygendialogengine.h"
+#include "oxygenflatwidgetengine.h"
 #include "oxygengroupboxengine.h"
 #include "oxygengroupboxlabelengine.h"
 #include "oxygenhook.h"
@@ -110,6 +111,10 @@ namespace Oxygen
         DialogEngine& dialogEngine( void ) const
         { return *_dialogEngine; }
 
+        //! flat widget
+        FlatWidgetEngine& flatWidgetEngine( void ) const
+        { return *_flatWidgetEngine; }
+
         //! groupbox engine
         GroupBoxEngine& groupBoxEngine( void ) const
         { return *_groupBoxEngine; }
@@ -236,6 +241,9 @@ namespace Oxygen
         //! dialog engine
         DialogEngine* _dialogEngine;
 
+        //! flat widget
+        FlatWidgetEngine* _flatWidgetEngine;
+
         //! groupbox engine
         GroupBoxEngine* _groupBoxEngine;
 
