@@ -20,6 +20,7 @@
 
 #include "oxygencomboboxentrydata.h"
 #include "../oxygengtkutils.h"
+#include "../config.h"
 
 #include <gtk/gtk.h>
 #include <iostream>
@@ -32,6 +33,12 @@ namespace Oxygen
     void ComboBoxEntryData::disconnect( GtkWidget* widget )
     {
 
+        #if OXYGEN_DEBUG
+        std::cerr << "Oxygen::ComboBoxEntryData::connect - widget: " << widget << std::endl;
+        #endif
+
+        _list = 0L;
+
         HoverData::disconnect( widget );
         _entry.disconnect();
         _button.disconnect();
@@ -44,7 +51,6 @@ namespace Oxygen
         assert( !_button._widget );
 
         _button._destroyId.connect( G_OBJECT(widget), "destroy", G_CALLBACK( childDestroyNotifyEvent ), this );
-        _button._styleChangeId.connect( G_OBJECT(widget), "style-set", G_CALLBACK( childStyleChangeNotifyEvent ), this );
         _button._enterId.connect( G_OBJECT(widget), "enter-notify-event", (GCallback)enterNotifyEvent, this );
         _button._leaveId.connect( G_OBJECT(widget), "leave-notify-event", (GCallback)leaveNotifyEvent, this );
         _button._toggledId.connect( G_OBJECT(widget), "toggled", G_CALLBACK( childToggledEvent ), this );
@@ -62,7 +68,6 @@ namespace Oxygen
         #endif
 
         _entry._destroyId.connect( G_OBJECT(widget), "destroy", G_CALLBACK( childDestroyNotifyEvent ), this );
-        _entry._styleChangeId.connect( G_OBJECT(widget), "style-set", G_CALLBACK( childStyleChangeNotifyEvent ), this );
         _entry._enterId.connect( G_OBJECT(widget), "enter-notify-event", (GCallback)enterNotifyEvent, this );
         _entry._leaveId.connect( G_OBJECT(widget), "leave-notify-event", (GCallback)leaveNotifyEvent, this );
         _entry._widget = widget;
@@ -119,7 +124,6 @@ namespace Oxygen
 
         if( !_widget ) return;
         _destroyId.disconnect();
-        _styleChangeId.disconnect();
         _enterId.disconnect();
         _leaveId.disconnect();
         _toggledId.disconnect();
@@ -136,11 +140,6 @@ namespace Oxygen
         return FALSE;
     }
 
-    //____________________________________________________________________________________________
-    void ComboBoxEntryData::childStyleChangeNotifyEvent( GtkWidget* widget, GtkStyle*, gpointer data )
-    { static_cast<ComboBoxEntryData*>(data)->unregisterChild( widget ); }
-
-
     //____________________________________________________________________________________________
     void ComboBoxEntryData::childToggledEvent( GtkWidget* widget, gpointer data)
     {
