@@ -26,6 +26,8 @@
 #include "oxygenrgba.h"
 #include "oxygenshadowhelper.h"
 
+#include "config.h"
+
 #include <iostream>
 #include <cairo/cairo.h>
 #include <cairo/cairo-xlib.h>
@@ -40,11 +42,21 @@ namespace Oxygen
         _size(0),
         _atom(0),
         _hooksInitialized( false )
-    {}
+    {
+        #if OXYGEN_DEBUG
+        std::cerr << "Oxygen::ShadowHelper::ShadowHelper" << std::endl;
+        #endif
+    }
 
     //______________________________________________
     ShadowHelper::~ShadowHelper( void )
-    { reset(); }
+    {
+        #if OXYGEN_DEBUG
+        std::cerr << "Oxygen::ShadowHelper::~ShadowHelper" << std::endl;
+        #endif
+
+        reset();
+    }
 
     //______________________________________________
     void ShadowHelper::reset( void )
@@ -57,6 +69,10 @@ namespace Oxygen
         GdkScreen* screen = gdk_screen_get_default();
         if( !screen ) return;
 
+        #if OXYGEN_DEBUG
+        std::cerr << "Oxygen::ShadowHelper::~ShadowHelper - reset" << std::endl;
+        #endif
+
         Display* display( GDK_DISPLAY_XDISPLAY( gdk_screen_get_display( screen ) ) );
 
         // round pixmaps
@@ -192,8 +208,7 @@ namespace Oxygen
             hint == GDK_WINDOW_TYPE_HINT_DROPDOWN_MENU ||
             hint == GDK_WINDOW_TYPE_HINT_POPUP_MENU ||
             hint == GDK_WINDOW_TYPE_HINT_COMBO ||
-            hint == GDK_WINDOW_TYPE_HINT_TOOLTIP ||
-            ( hint == GDK_WINDOW_TYPE_HINT_UTILITY && !widget->parent && _applicationName.isXul(widget) );
+            hint == GDK_WINDOW_TYPE_HINT_TOOLTIP;
     }
 
     //______________________________________________
@@ -262,7 +277,7 @@ namespace Oxygen
         if( _roundPixmaps.empty() )
         {
 
-           _roundPixmaps.push_back( createPixmap( _roundTiles.surface( 1 ), shadowOpacity ) );
+            _roundPixmaps.push_back( createPixmap( _roundTiles.surface( 1 ), shadowOpacity ) );
             _roundPixmaps.push_back( createPixmap( _roundTiles.surface( 2 ), shadowOpacity ) );
             _roundPixmaps.push_back( createPixmap( _roundTiles.surface( 5 ), shadowOpacity ) );
             _roundPixmaps.push_back( createPixmap( _roundTiles.surface( 8 ), shadowOpacity ) );
@@ -339,6 +354,9 @@ namespace Oxygen
             << std::endl;
         #endif
 
+        // check widget
+        if( !GTK_IS_WIDGET( widget ) ) return;
+
         // make sure handles and atom are defined
         createPixmapHandles();
 
@@ -395,7 +413,7 @@ namespace Oxygen
     void ShadowHelper::uninstallX11Shadows( GtkWidget* widget ) const
     {
 
-        if( !widget ) return;
+        if( !GTK_IS_WIDGET( widget ) ) return;
 
         GdkWindow  *window = gtk_widget_get_window( widget );
         GdkDisplay *display = gtk_widget_get_display( widget );
